@@ -1,13 +1,13 @@
 #
 # This file is part of Config-Model-TkUI
 #
-# This software is Copyright (c) 2008-2019 by Dominique Dumont <ddumont@cpan.org>.
+# This software is Copyright (c) 2008-2021 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
-package Config::Model::Tk::AnyViewer 1.370;
+package Config::Model::Tk::AnyViewer 1.372;
 
 use strict;
 use warnings;
@@ -16,6 +16,7 @@ use Carp;
 use Tk::Photo;
 use Tk::ROText;
 use Tk::Dialog;
+use Config::Model 2.139;
 use Config::Model::TkUI;
 use Log::Log4perl qw(get_logger :levels);
 use Tk::Pod::Text;
@@ -72,7 +73,8 @@ sub add_info_button {
     my $cw = shift;
     my $frame = shift || $cw;
 
-    my ( $elt_name, @items ) = $cw->get_info;
+    my $elt_name = $cw->cme_object->element_name;
+    my @items = $cw->cme_object->get_info;
 
     my $title = "Info on " . $cw->{config_class_name};
     $title .= ':' . $elt_name if $elt_name;
