@@ -1,13 +1,13 @@
 #
 # This file is part of Config-Model-TkUI
 #
-# This software is Copyright (c) 2008-2019 by Dominique Dumont <ddumont@cpan.org>.
+# This software is Copyright (c) 2008-2021 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
-package Config::Model::Tk::HashViewer 1.370;
+package Config::Model::Tk::HashViewer 1.372;
 
 use strict;
 use warnings;
@@ -70,29 +70,9 @@ sub Populate {
     $cw->SUPER::Populate($args);
 }
 
-sub get_info {
+sub cme_object {
     my $cw = shift;
-
-    my $hash = $cw->{hash};
-
-    my @items = (
-        'type : ' . $hash->get_type . ( $hash->ordered ? '(ordered)' : '' ),
-        'index : ' . $hash->index_type,
-        'cargo : ' . $hash->cargo_type,
-    );
-
-    if ( $hash->cargo_type eq 'node' ) {
-        push @items, "cargo class: " . $hash->config_class_name;
-    }
-
-    foreach my $what (qw/min_index max_index max_nb warn_if_key_match warn_unless_key_match/) {
-        my $v   = $hash->$what();
-        my $str = $what;
-        $str =~ s/_/ /g;
-        push @items, "$str: $v" if defined $v;
-    }
-
-    return ( $hash->element_name, @items );
+    return $cw->{hash};
 }
 
 1;
