@@ -1,13 +1,13 @@
 #
 # This file is part of Config-Model-TkUI
 #
-# This software is Copyright (c) 2008-2019 by Dominique Dumont <ddumont@cpan.org>.
+# This software is Copyright (c) 2008-2021 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
-package Config::Model::Tk::LeafEditor 1.370;
+package Config::Model::Tk::LeafEditor 1.372;
 
 use strict;
 use warnings;
@@ -203,14 +203,16 @@ sub try {
         my $e_w = $cw->{e_widget};
 
         # tk widget use a reference
-        $v =
-            defined $e_w
-            ? $e_w->get( '1.0', 'end' )
-            : $cw->{value};
+        if (defined $e_w) {
+            $v = $e_w->get( '1.0', 'end' );
+            chomp $v;
+        }
+        else {
+            $v = $cw->{value};
+        }
     }
 
     $v = '' unless defined $v;
-    chomp $v;
 
     $logger->debug("try: value $v");
     require Tk::Dialog;
@@ -258,15 +260,23 @@ sub store {
     my $e_w = $cw->{e_widget};
 
     # tk widget use a reference
-    my $v = defined $arg ? $arg
-          : defined $e_w ? $e_w->get( '1.0', 'end' )
-          :                $cw->{value};
+    my $v;
+    if (defined $arg) {
+        $v = $arg;
+    }
+    elsif (defined $e_w) {
+        $v = $e_w->get( '1.0', 'end' );
+        chomp $v; # Tk::Text::get always add a "\n";
+    }
+    else {
+        $v = $cw->{value};
+    }
 
     $v = '' unless defined $v;
-    chomp $v;
+
+    my $leaf = $cw->{leaf};
 
     print "Storing '$v'\n";
-    my $leaf = $cw->{leaf};
 
     eval { $leaf->store($v); };
 
@@ -341,7 +351,9 @@ sub exec_external_editor {
     my $pt = Path::Tiny->tempfile(@pt_args);
 
     die "Can't create Path::Tiny:$!" unless defined $pt;
-    $pt->spew_utf8( $cw->{e_widget}->get( '1.0', 'end' ) );
+    my $orig_data = $cw->{e_widget}->get( '1.0', 'end' );
+    chomp $orig_data; # Tk::Text::get always add a "\n";
+    $pt->spew_utf8( $orig_data );
 
     # See mastering Perl/Tk p382
     my $h = $cw->{ed_handle} = IO::Handle->new;
